#
# spec file for package ttf-converter
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{suse_version} < 1550
%define primary_python python3
%endif
Name:           ttf-converter
Version:        1.0.7
Release:        3.3
Summary:        Python script that converts fonts to TrueType format
License:        GPL-3.0-only
URL:            https://github.com/antlarr-suse/ttf-converter
Source:         ttf-converter-%{version}.tar.xz
BuildRequires:  python-rpm-macros
Requires:       %{primary_python}-base
Requires:       fontforge
Requires:       ftdump
BuildArch:      noarch

%description
This is a Python script that converts fonts to TrueType/OpenType
format. It uses the FontForge Python bindings to read/process and
write any font format. Also, as part of the conversion process, the
script tries to fix inconsistencies and do necessary changes to the
font to honor the TTF/OTF format specs.

Though TrueType is often used synonymously with outline fonts, it
supports embedded bitmaps. ttf-converter leaves the glyph kind
(outline/bitmapped) unchanged.

For converting a font to have scalable outline glyphs, see vfontas
instead.

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{_bindir}
install ttf-converter %{buildroot}%{_bindir}
%python3_fix_shebang

%files
%license LICENSE
%doc README.md
%{_bindir}/ttf-converter

%changelog
* Fri Feb  2 2024 Antonio Larrosa <alarrosa@suse.com>
- Fix for SLE 15 where %%primary_python is not defined.
* Thu Feb  1 2024 Antonio Larrosa <alarrosa@suse.com>
- Reduce the BuildRequires from python3 to just python-rpm-macros
  and Require: %%{primary_python}-base instead of python3-base
  which might be off for a short time when %%primary_python changes.
* Thu Feb  1 2024 Antonio Larrosa <alarrosa@suse.com>
- Use %%python3_fix_shebang
* Thu Sep 28 2023 Jan Engelhardt <jengelh@inai.de>
- Update %%description with content from upstream README.
* Thu May  4 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.0.7:
  * Explicitly flush the file for following read operation
  * Fixed Unused mode warning
  * Code style cleanups
  * Update description inside README.md
* Tue Jun 30 2020 alarrosa@suse.com
- Update to version 1.0.6:
  * Standarize output when converting vector and bitmap fonts
  * Add more subfamilies fixes (boo#1169444)
* Mon Jun 29 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.0.5:
  * Add --family and --subfamily arguments to force values on those
    fields
  * Add parameters to fix glyph unicode values
  - -fix-glyph-unicode : Try to fix unicode points and glyph names
    based on glyph names containing hexadecimal codes (like
    "$0C00", "char12345" or "uni004F")
  - -replace-unicode-values: When passed 2 comma separated numbers
    a,b the glyph with an unicode value of a is replaced with the
    unicode value b. Can be used more than once.
  - -shift-unicode-values: When passed 3 comma separated numbers
    a,b,c this shifts the unicode values of glyphs between a and b
    (both included) by adding c. Can be used more than once.
  * Add --bitmapTransform parameter to transform bitmap glyphs. When
    used, all glyphs are modified with the transformation function and
    values passed as parameters. The parameter has three values
    separated by commas: fliph|flipv|rotate90cw|rotate90ccw|
    rotate180|skew|transmove,xoff,yoff
    (boo#1169444)
* Thu Jun 25 2020 alarrosa@suse.com
- Update to version 1.0.4:
  * Add support to convert bitmap fonts (boo#1169444)
  * Rename MediumItalic subfamily to Medium Italic
  * Show some more information when removing duplicated glyphs
* Mon Jun 22 2020 alarrosa@suse.com
- Update to version 1.0.3:
  * Bump version to 1.0.3
  * Add a --force-monospaced argument instead of hardcoding
    font names
  * Fix print format
  * Convert `BoldCond` subfamily to `Bold Condensed`
* Fri Jun 19 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.0.2 (boo#1169444 #c41)
  * Fixes for Monospaced fonts and force the Nimbus Mono L font
    to be Monospaced
  * Add a --version argument
* Fri Jun 19 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.0.1 (boo#1169444 #c41)
  * Fix subfamily names so the converted font's subfamily match
    the original ones
* Mon Apr 20 2020 Antonio Larrosa <alarrosa@suse.com>
- Initial release of ttf-converter 1.0 (boo#1169444)
